@@ -101,6 +101,7 @@ static const unsigned short punct_chars[] = {',','.','?','!',':',';',
   0x1366,
   0x1367,
   0x1368,
+  0x10fb,  // Georgian paragraph
 
   0x3001,  // ideograph comma
   0x3002,  // ideograph period
@@ -142,7 +143,8 @@ static const unsigned int punct_attributes [] = { 0,
   CLAUSE_COLON,      // Ethiopic colon
   CLAUSE_COLON,      // Ethiopic preface colon
   CLAUSE_QUESTION,   // Ethiopic question mark
-  CLAUSE_PERIOD,     // Ethiopic paragraph
+  CLAUSE_PARAGRAPH,     // Ethiopic paragraph
+  CLAUSE_PARAGRAPH,     // Georgian paragraph
 
   CLAUSE_COMMA+0x8000,      // ideograph comma
   CLAUSE_PERIOD+0x8000,     // ideograph period
